@@ -22,8 +22,11 @@ Implementation of Prolog / ProbLog builtins.
     limitations under the License.
 """
 
-from __future__ import print_function
+import sys
 
+from .engine import UnknownClauseInternal, UnknownClause
+from .engine_unify import unify_value, UnifyError, substitute_simple
+from .errors import GroundingError, UserError
 from .logic import (
     term2str,
     Term,
@@ -37,13 +40,6 @@ from .logic import (
     AnnotatedDisjunction,
     Object,
 )
-from .program import PrologFile
-from .errors import GroundingError, UserError
-from .engine_unify import unify_value, UnifyError, substitute_simple
-from .engine import UnknownClauseInternal, UnknownClause
-import inspect
-import os
-import sys
 
 
 class builtin(object):
@@ -120,14 +116,14 @@ def add_standard_builtins(engine, b=None, s=None, sp=None):
     engine.add_builtin("false", 0, b(_builtin_fail))  # -3
 
     engine.add_builtin("=", 2, s(_builtin_eq))  # -4
-    engine.add_builtin("\=", 2, b(_builtin_neq))  # -5
+    engine.add_builtin("\\=", 2, b(_builtin_neq))  # -5
 
     engine.add_builtin("findall", 3, sp(_builtin_findall))  # -6
     engine.add_builtin("all", 3, sp(_builtin_all))  # -7
     engine.add_builtin("all_or_none", 3, sp(_builtin_all_or_none))  # -8
 
     engine.add_builtin("==", 2, b(_builtin_same))
-    engine.add_builtin("\==", 2, b(_builtin_notsame))
+    engine.add_builtin("\\==", 2, b(_builtin_notsame))
 
     engine.add_builtin("is", 2, s(_builtin_is))
 
@@ -135,7 +131,7 @@ def add_standard_builtins(engine, b=None, s=None, sp=None):
     engine.add_builtin("<", 2, b(_builtin_lt))
     engine.add_builtin("=<", 2, b(_builtin_le))
     engine.add_builtin(">=", 2, b(_builtin_ge))
-    engine.add_builtin("=\=", 2, b(_builtin_val_neq))
+    engine.add_builtin("=\\=", 2, b(_builtin_val_neq))
     engine.add_builtin("=:=", 2, b(_builtin_val_eq))
 
     engine.add_builtin("var", 1, b(_builtin_var))
@@ -234,6 +230,7 @@ def add_standard_builtins(engine, b=None, s=None, sp=None):
         engine.add_builtin("call_in_scope", i + 1, _builtin_calln_in_scope)
 
     engine.add_builtin("find_scope", 2, s(_builtin_find_scope))
+    #engine.add_builtin("forall", 2, s(_builtin_forall)) TODO: Add forall as built-in here
 
     builtin.add_builtins(engine, b, s, sp)
 
@@ -772,7 +769,7 @@ def _builtin_eq(arg1, arg2, **kwdargs):
 
 # noinspection PyUnusedLocal
 def _builtin_neq(arg1, arg2, **kwdargs):
-    """``A \= B``
+    """``A \\= B``
         A and B not both variables
     """
     try:
@@ -784,7 +781,7 @@ def _builtin_neq(arg1, arg2, **kwdargs):
 
 # noinspection PyUnusedLocal
 def _builtin_notsame(arg1, arg2, **kwdargs):
-    """``A \== B``"""
+    """``A \\== B``"""
     return not arg1 == arg2
 
 
@@ -847,10 +844,10 @@ def _builtin_ge(arg1, arg2, engine=None, **k):
 
 
 def _builtin_val_neq(a, b, engine=None, **k):
-    """``A =\= B``
+    """``A =\\= B``
         A and B are ground
     """
-    check_mode((a, b), ["gg"], functor="=\=", **k)
+    check_mode((a, b), ["gg"], functor="=\\=", **k)
     a_value = a.compute_value(engine.functions)
     b_value = b.compute_value(engine.functions)
     if a_value is None or b_value is None:
@@ -1612,7 +1609,7 @@ def _builtin_sample_uniform(key, lst, result, database=None, target=None, **kwda
     The first argument is used as an identifier such that calls with the same key enforce mutual \
     exclusivity on the results, that is, the probability of
 
-        sample_uniform(K,L,R1), sample_uniform(K,L,R2), R1 \== R2
+        sample_uniform(K,L,R1), sample_uniform(K,L,R2), R1 \\== R2
 
     is 0.
 
@@ -1729,6 +1726,8 @@ def _builtin_try_call(term, **kwdargs):
         return _builtin_call(term, **kwdargs)
     except UnknownClause:
         return True, kwdargs["callback"].notifyComplete()
+    except:
+        return True, kwdargs["callback"].notifyComplete()
 
 
 def _builtin_call(
@@ -1827,7 +1826,6 @@ class IndirectCallCycleError(GroundingError):
 
 
 def _build_scope(term):
-
     if term.functor == "'&'":
         a = _build_scope(term.args[0])
         b = _build_scope(term.args[1])
