@@ -16,17 +16,14 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from __future__ import print_function
-
 import itertools
-from datetime import datetime
-import re
-from functools import reduce
-import sys
-import math
-from collections import Counter, defaultdict, OrderedDict
 import logging
-
+import math
+import re
+import sys
+from collections import Counter, defaultdict, OrderedDict
+from datetime import datetime
+from functools import reduce
 
 logger = logging.getLogger("be.kuleuven.cs.dtai.problog.cpd")
 
@@ -538,9 +535,9 @@ class Variable(object):
                     # This is the negation of one value
                     (new_value,) = frozenset(self.values) - value
                     if value_as_term:
-                        return "\+" + self.clean() + '("' + str(new_value) + '")'
+                        return "\\+" + self.clean() + '("' + str(new_value) + '")'
                     else:
-                        return "\+" + self.clean() + "_" + self.clean(str(new_value))
+                        return "\\+" + self.clean() + "_" + self.clean(str(new_value))
                 else:
                     if value_as_term:
                         return (
@@ -574,7 +571,7 @@ class Variable(object):
             if self.values[self.boolean_true] == value:
                 return self.clean()
             elif self.values[1 - self.boolean_true] == value:
-                return "\+" + self.clean()
+                return "\\+" + self.clean()
             else:
                 raise Exception("Unknown value: {} = {}".format(self.name, value))
 
@@ -954,7 +951,9 @@ class Factor(object):
             ]
             # lines.append('false_constraints :- '+', '.join(['\+'+l for l in head_lits])+'.')
             lines.append(
-                "constraint([" + ", ".join(["\+" + l for l in head_lits]) + "], false)."
+                "constraint(["
+                + ", ".join(["\\+" + l for l in head_lits])
+                + "], false)."
             )
             for lit1, lit2 in itertools.combinations(head_lits, 2):
                 # lines.append('false_constraints :- {}, {}.'.format(lit1, lit2))
