@@ -38,24 +38,22 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from __future__ import print_function
-
-import sys
-
-from problog.program import PrologFile
-from problog.logic import Term, Constant, ArithmeticError, term2list, list2term
-from problog.engine import DefaultEngine, UnknownClause, UnknownClauseInternal
-from problog.engine_builtin import check_mode, builtin_simple
-from problog.formula import LogicFormula
-from problog.errors import process_error, GroundingError
-from problog.util import start_timer, stop_timer, format_dictionary, init_logger
-from problog.engine_unify import UnifyError, unify_value
-import random
+import logging
 import math
+import random
 import signal
+import sys
 import time
 import traceback
-import logging
+
+from problog.engine import DefaultEngine, UnknownClause, UnknownClauseInternal
+from problog.engine_builtin import check_mode
+from problog.engine_unify import UnifyError, unify_value
+from problog.errors import process_error, GroundingError
+from problog.formula import LogicFormula
+from problog.logic import Term, Constant, ArithmeticError, term2list
+from problog.program import PrologFile
+from problog.util import start_timer, stop_timer, format_dictionary, init_logger
 
 try:
     from tqdm import tqdm
@@ -195,7 +193,17 @@ class SampledFormula(LogicFormula):
             return None
         return self.values[key - 1]
 
-    def add_atom(self, identifier, probability, group=None, name=None, source=None):
+    def add_atom(
+        self,
+        identifier,
+        probability,
+        group=None,
+        name=None,
+        source=None,
+        cr_extra=True,
+        is_extra=False,
+    ):
+        # def add_atom(self, identifier, probability, group=None, name=None, source=None):
         if probability is None:
             return 0
 
@@ -323,13 +331,13 @@ class SampledFormula(LogicFormula):
                     if not as_evidence:
                         lines.append("%s = %s." % (str(k), val))
             elif as_evidence:
-                lines.append(base % ("\+" + str(k)))
+                lines.append(base % ("\\+" + str(k)))
         if with_facts:
             for k, v in self.facts.items():
                 if v == 0:
                     lines.append(base % str(translate(db, k)))
                 elif v is None:
-                    lines.append(base % ("\+" + str(translate(db, k))))
+                    lines.append(base % ("\\+" + str(translate(db, k))))
 
         if oneline:
             sep = " "
@@ -392,6 +400,7 @@ def builtin_shuffle(lst_in, lst_out, **kwargs):
 
 def builtin_previous(term, default, engine=None, target=None, callback=None, **kwdargs):
     # retrieve term from previous sample, default action if no previous sample
+    # See "A. Dries, Declarative data generation with ProbLog, 2015" for more info
 
     if engine.previous_result is None:
         results = engine.call(default, subcall=True, target=target, **kwdargs)
@@ -553,7 +562,6 @@ def sample(
 
 
 def verify_evidence(engine, db, ev_target, q_target):
-
     if ev_target is None:
         evidence = engine.query(db, Term("evidence", None, None))
         evidence += engine.query(db, Term("evidence", None))
@@ -724,7 +732,7 @@ def print_result_json(d, output, **kwdargs):
     return 0
 
 
-def main(args, result_handler=None):
+def get_argument_parser():
     import argparse
 
     parser = argparse.ArgumentParser()
@@ -796,7 +804,11 @@ def main(args, result_handler=None):
         help="Pass additional arguments to the cmd_args builtin.",
     )
     parser.add_argument("--progress", help="show progress", action="store_true")
+    return parser
 
+
+def main(args, result_handler=None):
+    parser = get_argument_parser()
     args = parser.parse_args(args)
 
     init_logger(args.verbose, "problog_sample")
@@ -830,20 +842,20 @@ def main(args, result_handler=None):
     else:
         outformat = "str"
         result_handler = print_result
+
+    final_result = None
     try:
         if args.estimate:
             results = estimate(pl, **vars(args))
             print(format_dictionary(results))
         else:
-            result_handler(
-                (True, sample(pl, format=outformat, **vars(args))),
-                output=outf,
-                oneline=args.oneline,
-            )
+            final_result = (True, sample(pl, format=outformat, **vars(args)))
+            result_handler(final_result, output=outf, oneline=args.oneline)
     except Exception as err:
         trace = traceback.format_exc()
         err.trace = trace
-        result_handler((False, err), output=outf)
+        final_result = (False, err)
+        result_handler(final_result, output=outf)
 
     if args.timeout:
         stop_timer()
@@ -851,6 +863,8 @@ def main(args, result_handler=None):
     if args.output is not None:
         outf.close()
 
+    return final_result
+
 
 if __name__ == "__main__":
     main(sys.argv[1:])
