@@ -16,9 +16,9 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-from __future__ import print_function
-
-import os, sys, subprocess, traceback, json
+import json
+import os
+import sys
 
 sys.setrecursionlimit(10000)
 
@@ -27,7 +27,8 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "../"
 from problog.program import PrologFile
 from problog.errors import process_error
 
-from learning import lfi
+from problog.learning import lfi
+
 
 # from problog.sdd_formula import SDD
 
